Learn R Programming

surveydata (version 0.1-11)

lapplyNames: Applies function only to named elements of a list.

Description

This is useful to clean only some columns in a list (or data.frame or surveydata object). This is just a wrapper around lapply where only the named elements are changed.

Usage

lapplyNames(x, names, FUN, ...)

Arguments

x
List
names
Character vector identifying which elements of the list to apply FUN
FUN
The function to apply.
...
Additional arguments passed to FUN

See Also

Other Tools: qOrder