Learn R Programming

surveydata (version 0.1-11)

removeAllDK: Removes "Do not know" and other similar words from factor levels in data frame.

Description

Removes "Do not know" and other similar words from factor levels in data frame

Usage

removeAllDK(x, dk = NULL)

Arguments

x
List or data frame
dk
Character vector, containing search terms, e.g. c("Do not know", "DK"). These terms will be replaced by NA. If NULL, will default to c("I don't know", "Don't Know", "Don't know", "Dont know" , "DK")

Value

  • A data frame

See Also

hasDK and removeDK Other Functions to clean data: encToInt, fixCommonEncodingProblems, fixLevels01, fixLevels01R, fixLevels01SPSS, hasDK, intToEnc, leveltestR, leveltestSPSS, removeDK