Learn R Programming

surveydata (version 0.1-11)

splitCommonUnique: Get common and unique text in question based on regex pattern identification

Description

Get common and unique text in question based on regex pattern identification

Usage

splitCommonUnique(x, ptn = NULL)

Arguments

x
A character vector
ptn
A regex pattern that defines how the string should be split into common and unique elements

See Also

Other Question functions: qText, qTextCommon, qTextUnique, questions, which.q