The surveydata package exposes functionality to support some of the dplyr verbs, e.g. dplyr::filter(). The computation is performed by dplyr, and the resulting object is of class surveydata (as well as the dplyr result).
Usage
# S3 method for surveydata
mutate(.data, ...)
# S3 method for surveydata
as_tibble(x, ..., .name_repair, rownames)